@@ -151,10 +151,7 @@ func (s *RegisterCommand) ask(key, prompt string, allowEmptyOptional ...bool) st
 		return result
 	}
 
-	for {
-		if s.askOnce(prompt, &result, allowEmpty) {
-			break
-		}
+	for !s.askOnce(prompt, &result, allowEmpty) {
 	}
 
 	return result
@@ -601,5 +598,5 @@ func accessLevelValid(levels []AccessLevel, givenLevel AccessLevel) bool {
 }
 
 func init() {
-	common.RegisterCommand2("register", "register a new runner", newRegisterCommand())
+	common.RegisterCommand("register", "register a new runner", newRegisterCommand())
 }
