@@ -2,6 +2,8 @@ package common
 
 import (
 	"context"
+	"crypto/sha256"
+	"encoding/hex"
 	"errors"
 	"fmt"
 	"io"
@@ -224,6 +226,8 @@ func (b *Build) ProjectUniqueShortName() string {
 	return dns.MakeRFC1123Compatible(projectUniqueName)
 }
 
+// ProjectUniqueName returns a unique name for a runner && project. It uses the runner's short description, thus uses a
+// truncated token in it's human readable form.
 func (b *Build) ProjectUniqueName() string {
 	projectUniqueName := fmt.Sprintf(
 		"runner-%s-project-%d-concurrent-%d",
@@ -235,6 +239,33 @@ func (b *Build) ProjectUniqueName() string {
 	return dns.MakeRFC1123Compatible(projectUniqueName)
 }
 
+// ProjectRealUniqueName is similar to its sister methods, and returns a unique name for the runner && project.
+// It uses the following parts to generate a truncated¹ sha256 sum:
+//   - the runner's full token
+//   - the runner's system ID
+//   - the project ID
+//   - the project runner ID
+//
+// With that the name is not susceptible to name clashes, when tokens are similar enough and therefore are the same
+// after getting the runner's short description (i.e. after the token has been truncated)
+//
+// ¹ we truncate the resulting sum from original 32 bytes to 16 bytes, to give us and users a shorter name, thus shorter
+// volume names when used in the docker volume manager. Truncating to 16 bytes (32 chars when hex encoded, the same
+// length as an hex encoded md5sum) is cryptographically sound, it's still strong against collisions.
+func (b *Build) ProjectRealUniqueName() string {
+	const byteLen = 16
+
+	data := fmt.Sprintf("%s-%s-%d-%d",
+		b.Runner.GetToken(),
+		b.Runner.GetSystemID(),
+		b.JobInfo.ProjectID,
+		b.ProjectRunnerID,
+	)
+
+	sum := sha256.Sum256([]byte(data))
+	return "runner-" + hex.EncodeToString(sum[:byteLen])
+}
+
 func (b *Build) ProjectSlug() (string, error) {
 	url, err := url.Parse(b.GitInfo.RepoURL)
 	if err != nil {
@@ -1343,13 +1374,10 @@ func (b *Build) RefreshAllVariables() {
 	b.buildSettings = nil
 }
 
-func (b *Build) GetAllVariables() JobVariables {
-	if b.allVariables != nil {
-		return b.allVariables
-	}
-
+// getBaseVariablesBeforeJob returns the base variables that come before job variables.
+func (b *Build) getBaseVariablesBeforeJob() JobVariables {
 	variables := make(JobVariables, 0)
-	variables = append(variables, b.GetDefaultFeatureFlagsVariables()...)
+
 	if b.Image.Name != "" {
 		variables = append(
 			variables,
@@ -1361,7 +1389,14 @@ func (b *Build) GetAllVariables() JobVariables {
 	}
 	variables = append(variables, b.GetDefaultVariables()...)
 	variables = append(variables, b.GetCITLSVariables()...)
-	variables = append(variables, b.Variables...)
+
+	return variables
+}
+
+// getBaseVariablesAfterJob returns the base variables that come after job variables.
+func (b *Build) getBaseVariablesAfterJob() JobVariables {
+	variables := make(JobVariables, 0)
+
 	variables = append(variables, b.GetSharedEnvVariable())
 	variables = append(variables, AppVersion.Variables()...)
 	variables = append(variables, b.secretsVariables...)
@@ -1370,6 +1405,89 @@ func (b *Build) GetAllVariables() JobVariables {
 		Key: tempProjectDirVariableKey, Value: b.TmpProjectDir(), Public: true, Internal: true,
 	})
 
+	return variables
+}
+
+// getVariablesForFeatureFlagResolution returns an initial set of variables that will be used
+// to resolve feature flag settings. This is used only during initSettings.
+func (b *Build) getVariablesForFeatureFlagResolution() JobVariables {
+	variables := make(JobVariables, 0)
+
+	variables = append(variables, b.GetDefaultFeatureFlagsVariables()...)
+	variables = append(variables, b.getBaseVariablesBeforeJob()...)
+	variables = append(variables, b.Variables...)
+	variables = append(variables, b.getBaseVariablesAfterJob()...)
+
+	return variables.Expand()
+}
+
+// getResolvedFeatureFlags returns resolved feature flags with TOML precedence.
+// This assumes build settings have been initialized. This is
+// part of the two-phase feature flag resolution process that ensures
+// TOML settings take precedence over job variables.
+func (b *Build) getResolvedFeatureFlags() JobVariables {
+	variables := make(JobVariables, 0)
+
+	if b.buildSettings == nil {
+		logrus.Warn("build settings are not initialized")
+		return variables
+	}
+
+	for _, featureFlag := range featureflags.GetAll() {
+		resolvedValue := b.buildSettings.FeatureFlags[featureFlag.Name]
+		variables = append(variables, JobVariable{
+			Key:      featureFlag.Name,
+			Value:    strconv.FormatBool(resolvedValue),
+			Public:   true,
+			Internal: true,
+			File:     false,
+		})
+	}
+
+	return variables
+}
+
+// getNonFeatureFlagJobVariables gets job variables, excluding feature flags to prevent double inclusion
+// and to maintain the precedence of TOML-configured feature flags over job variables.
+func (b *Build) getNonFeatureFlagJobVariables() JobVariables {
+	featureFlagNames := make(map[string]bool)
+	for _, ff := range featureflags.GetAll() {
+		featureFlagNames[ff.Name] = true
+	}
+
+	filtered := make(JobVariables, 0, len(b.Variables))
+	for _, variable := range b.Variables {
+		if !featureFlagNames[variable.Key] {
+			filtered = append(filtered, variable)
+		}
+	}
+
+	return filtered
+}
+
+// GetAllVariables() returns final variables with a consistent precedence order:
+// 1. Resolved feature flags (TOML takes precedence over job variables)
+// 2. Base variables that come before job variables
+// 3. Job variables (excluding feature flags to prevent overriding resolved values)
+// 4. Base variables that come after job variables
+func (b *Build) GetAllVariables() JobVariables {
+	if b.allVariables != nil {
+		return b.allVariables
+	}
+
+	// Phase 1: Ensure feature flags have been resolved.
+	if b.buildSettings == nil {
+		b.Settings()
+	}
+
+	variables := make(JobVariables, 0)
+
+	// Phase 2: Add resolved feature flags first (maintains original precedence order)
+	variables = append(variables, b.getResolvedFeatureFlags()...)
+	variables = append(variables, b.getBaseVariablesBeforeJob()...)
+	variables = append(variables, b.getNonFeatureFlagJobVariables()...)
+	variables = append(variables, b.getBaseVariablesAfterJob()...)
+
 	b.allVariables = variables.Expand()
 
 	return b.allVariables
@@ -1542,6 +1660,10 @@ func (b *Build) GetGitCleanFlags() []string {
 	return b.Settings().GitCleanFlags
 }
 
+func (b *Build) GetGitCloneFlags() []string {
+	return b.Settings().GitCloneExtraFlags
+}
+
 func (b *Build) GetGitFetchFlags() []string {
 	return b.Settings().GitFetchExtraFlags
 }
