@@ -319,6 +319,7 @@ type GitInfo struct {
 	RefType          GitInfoRefType `json:"ref_type"`
 	Refspecs         []string       `json:"refspecs"`
 	Depth            int            `json:"depth"`
+	Protected        *bool          `json:"protected"`
 }
 
 type RunnerInfo struct {
@@ -828,12 +829,12 @@ func (j *JobResponse) NativeStepsRequested() bool {
 type Secrets map[string]Secret
 
 type Secret struct {
-	Vault             *VaultSecret            `json:"vault,omitempty"`
-	GCPSecretManager  *GCPSecretManagerSecret `json:"gcp_secret_manager,omitempty"`
-	AzureKeyVault     *AzureKeyVaultSecret    `json:"azure_key_vault,omitempty"`
-	Akeyless          *AkeylessSecret         `json:"akeyless,omitempty"`
-	AWSSecretsManager *AWSSecret              `json:"aws_secrets_manager,omitempty"`
-	File              *bool                   `json:"file,omitempty"`
+	Vault                *VaultSecret                `json:"vault,omitempty"`
+	GCPSecretManager     *GCPSecretManagerSecret     `json:"gcp_secret_manager,omitempty"`
+	AzureKeyVault        *AzureKeyVaultSecret        `json:"azure_key_vault,omitempty"`
+	AWSSecretsManager    *AWSSecret                  `json:"aws_secrets_manager,omitempty"`
+	GitLabSecretsManager *GitLabSecretsManagerSecret `json:"gitlab_secrets_manager,omitempty"`
+	File                 *bool                       `json:"file,omitempty"`
 }
 
 func (s Secrets) expandVariables(vars JobVariables) {
@@ -852,12 +853,12 @@ func (s Secret) expandVariables(vars JobVariables) {
 	if s.AzureKeyVault != nil {
 		s.AzureKeyVault.expandVariables(vars)
 	}
-	if s.Akeyless != nil {
-		s.Akeyless.expandVariables(vars)
-	}
 	if s.AWSSecretsManager != nil {
 		s.AWSSecretsManager.expandVariables(vars)
 	}
+	// NOTE: GitLab Secrets Manager doesn't support variable expansion
+	// The only user input from the CI config is the secret name which Rails
+	// transforms into the path. Everything else is generated internally by Rails.
 }
 
 // IsFile defines whether the variable should be of type FILE or no.
@@ -965,51 +966,6 @@ func (s *AzureKeyVaultServer) expandVariables(vars JobVariables) {
 	s.JWT = vars.ExpandValue(s.JWT)
 }
 
-type AkeylessSecret struct {
-	Name          string         `json:"name"`
-	DataKey       string         `json:"data_key"`
-	CertUserName  string         `json:"cert_user_name"`
-	PublicKeyData string         `json:"public_key_data"`
-	CsrData       string         `json:"csr_data"`
-	Server        AkeylessServer `json:"server"`
-}
-
-type AkeylessServer struct {
-	AccessId               string `json:"access_id"`
-	AccessKey              string `json:"access_key"`
-	AkeylessApiUrl         string `json:"akeyless_api_url"`
-	AkeylessAccessType     string `json:"akeyless_access_type"`
-	AkeylessToken          string `json:"akeyless_token"`
-	JWT                    string `json:"jwt"`
-	UidToken               string `json:"uid_token"`
-	GcpAudience            string `json:"gcp_audience"`
-	AzureObjectId          string `json:"azure_object_id"`
-	K8SServiceAccountToken string `json:"k8s_service_account_token"`
-	K8SAuthConfigName      string `json:"k8s_auth_config_name"`
-	GatewayCaCert          string `json:"gateway_ca_certificate"`
-}
-
-func (s *AkeylessSecret) expandVariables(vars JobVariables) {
-	s.Name = vars.ExpandValue(s.Name)
-	s.DataKey = vars.ExpandValue(s.DataKey)
-	s.CertUserName = vars.ExpandValue(s.CertUserName)
-	s.PublicKeyData = vars.ExpandValue(s.PublicKeyData)
-	s.CsrData = vars.ExpandValue(s.CsrData)
-	s.Server.expandVariables(vars)
-}
-
-func (s *AkeylessServer) expandVariables(vars JobVariables) {
-	s.JWT = vars.ExpandValue(s.JWT)
-	s.AkeylessApiUrl = vars.ExpandValue(s.AkeylessApiUrl)
-	s.AkeylessAccessType = vars.ExpandValue(s.AkeylessAccessType)
-	s.AkeylessToken = vars.ExpandValue(s.AkeylessToken)
-	s.UidToken = vars.ExpandValue(s.UidToken)
-	s.GcpAudience = vars.ExpandValue(s.GcpAudience)
-	s.AzureObjectId = vars.ExpandValue(s.AzureObjectId)
-	s.K8SServiceAccountToken = vars.ExpandValue(s.K8SServiceAccountToken)
-	s.K8SAuthConfigName = vars.ExpandValue(s.K8SAuthConfigName)
-}
-
 type VaultSecret struct {
 	Server VaultServer `json:"server"`
 	Engine VaultEngine `json:"engine"`
@@ -1093,6 +1049,38 @@ func (e *VaultEngine) expandVariables(vars JobVariables) {
 	e.Path = vars.ExpandValue(e.Path)
 }
 
+// GitLabSecretsManagerSecret represents a secret configuration for GitLab's native
+// secrets management system using OpenBao as the backend.
+type GitLabSecretsManagerSecret struct {
+	Server GitLabSecretsManagerServer `json:"server"`
+	Engine GitLabSecretsManagerEngine `json:"engine"`
+	Path   string                     `json:"path"`
+	Field  string                     `json:"field"`
+}
+
+// GitLabSecretsManagerServer contains the configuration for connecting to the
+// OpenBao server and authenticating via JWT.
+type GitLabSecretsManagerServer struct {
+	URL        string                               `json:"url"`
+	InlineAuth GitLabSecretsManagerServerInlineAuth `json:"inline_auth"`
+}
+
+// GitLabSecretsManagerServerInlineAuth holds the inline authentication configuration
+// for OpenBao JWT authentication. This allows the runner to authenticate on each
+// request without storing tokens.
+type GitLabSecretsManagerServerInlineAuth struct {
+	AuthMount string `json:"auth_mount"`
+	JWT       string `json:"jwt"`
+	Role      string `json:"role"`
+}
+
+// GitLabSecretsManagerEngine specifies the secret engine configuration in OpenBao,
+// including the engine type and mount path.
+type GitLabSecretsManagerEngine struct {
+	Name string `json:"name"`
+	Path string `json:"path"`
+}
+
 func (j *JobResponse) RepoCleanURL() string {
 	return url_helpers.CleanURL(j.GitInfo.RepoURL)
 }
